summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsommersoft <sommersoft@gmail.com>2019-08-24 23:36:18 -0500
committersommersoft <sommersoft@gmail.com>2019-08-24 23:36:18 -0500
commitdf5568d993ad10bb6ef68fc0f01f8561f3a6c78d (patch)
treeb159b1273d698ea36fe28aefab7b0392baf159f7
parentb54fd961cb20333c1db0c84b7f61467681911554 (diff)
move Mixer & MixerVoice from 'audiocore' to 'audiomixer'
-rw-r--r--py/circuitpy_defns.mk8
-rw-r--r--py/circuitpy_mpconfig.h8
-rw-r--r--py/circuitpy_mpconfig.mk5
-rw-r--r--shared-bindings/audiocore/__init__.c6
-rw-r--r--shared-bindings/audioio/__init__.c7
-rw-r--r--shared-bindings/audiomixer/Mixer.c (renamed from shared-bindings/audiocore/Mixer.c)99
-rw-r--r--shared-bindings/audiomixer/Mixer.h (renamed from shared-bindings/audiocore/Mixer.h)34
-rw-r--r--shared-bindings/audiomixer/MixerVoice.c (renamed from shared-bindings/audiocore/MixerVoice.c)82
-rw-r--r--shared-bindings/audiomixer/MixerVoice.h (renamed from shared-bindings/audiocore/MixerVoice.h)30
-rw-r--r--shared-bindings/audiomixer/__init__.c63
-rw-r--r--shared-bindings/audiomixer/__init__.h34
-rw-r--r--shared-module/audiocore/__init__.c35
-rw-r--r--shared-module/audiomixer/Mixer.c (renamed from shared-module/audiocore/Mixer.c)52
-rw-r--r--shared-module/audiomixer/Mixer.h (renamed from shared-module/audiocore/Mixer.h)14
-rw-r--r--shared-module/audiomixer/MixerVoice.c (renamed from shared-module/audiocore/MixerVoice.c)20
-rw-r--r--shared-module/audiomixer/MixerVoice.h (renamed from shared-module/audiocore/MixerVoice.h)14
-rw-r--r--shared-module/audiomixer/__init__.c0
-rw-r--r--shared-module/audiomixer/__init__.h32
18 files changed, 346 insertions, 197 deletions
diff --git a/py/circuitpy_defns.mk b/py/circuitpy_defns.mk
index 675fe1aec..7ed9457d0 100644
--- a/py/circuitpy_defns.mk
+++ b/py/circuitpy_defns.mk
@@ -114,6 +114,9 @@ endif
ifeq ($(CIRCUITPY_AUDIOCORE),1)
SRC_PATTERNS += audiocore/%
endif
+ifeq ($(CIRCUITPY_AUDIOMIXER),1)
+SRC_PATTERNS += audiomixer/%
+endif
ifeq ($(CIRCUITPY_BITBANGIO),1)
SRC_PATTERNS += bitbangio/%
endif
@@ -305,10 +308,11 @@ SRC_SHARED_MODULE_ALL = \
audiopwmio/__init__.c \
audioio/__init__.c \
audiocore/__init__.c \
- audiocore/Mixer.c \
- audiocore/MixerVoice.c \
audiocore/RawSample.c \
audiocore/WaveFile.c \
+ audiomixer/__init__.c \
+ audiomixer/Mixer.c \
+ audiomixer/MixerVoice.c \
bitbangio/I2C.c \
bitbangio/OneWire.c \
bitbangio/SPI.c \
diff --git a/py/circuitpy_mpconfig.h b/py/circuitpy_mpconfig.h
index 393b7600c..8e44ee6c8 100644
--- a/py/circuitpy_mpconfig.h
+++ b/py/circuitpy_mpconfig.h
@@ -244,6 +244,13 @@ extern const struct _mp_obj_module_t audioio_module;
#define AUDIOIO_MODULE
#endif
+#if CIRCUITPY_AUDIOMIXER
+#define AUDIOMIXER_MODULE { MP_OBJ_NEW_QSTR(MP_QSTR_audiomixer), (mp_obj_t)&audiomixer_module },
+extern const struct _mp_obj_module_t audiomixer_module;
+#else
+#define AUDIOMIXER_MODULE
+#endif
+
#if CIRCUITPY_AUDIOPWMIO
#define AUDIOPWMIO_MODULE { MP_OBJ_NEW_QSTR(MP_QSTR_audiopwmio), (mp_obj_t)&audiopwmio_module },
extern const struct _mp_obj_module_t audiopwmio_module;
@@ -573,6 +580,7 @@ extern const struct _mp_obj_module_t ustack_module;
AUDIOBUSIO_MODULE \
AUDIOCORE_MODULE \
AUDIOIO_MODULE \
+ AUDIOMIXER_MODULE \
AUDIOPWMIO_MODULE \
BITBANGIO_MODULE \
BLEIO_MODULE \
diff --git a/py/circuitpy_mpconfig.mk b/py/circuitpy_mpconfig.mk
index 949cd1d18..b217abdce 100644
--- a/py/circuitpy_mpconfig.mk
+++ b/py/circuitpy_mpconfig.mk
@@ -94,6 +94,11 @@ endif
endif
CFLAGS += -DCIRCUITPY_AUDIOCORE=$(CIRCUITPY_AUDIOCORE)
+ifndef CIRCUITPY_AUDIOMIXER
+CIRCUITPY_AUDIOMIXER = $(CIRCUITPY_AUDIOIO)
+endif
+CFLAGS += -DCIRCUITPY_AUDIOMIXER=$(CIRCUITPY_AUDIOMIXER)
+
ifndef CIRCUITPY_BITBANGIO
CIRCUITPY_BITBANGIO = $(CIRCUITPY_FULL_BUILD)
endif
diff --git a/shared-bindings/audiocore/__init__.c b/shared-bindings/audiocore/__init__.c
index 9d82b1f99..c9d5a1cab 100644
--- a/shared-bindings/audiocore/__init__.c
+++ b/shared-bindings/audiocore/__init__.c
@@ -31,9 +31,9 @@
#include "shared-bindings/microcontroller/Pin.h"
#include "shared-bindings/audiocore/__init__.h"
-#include "shared-bindings/audiocore/Mixer.h"
#include "shared-bindings/audiocore/RawSample.h"
#include "shared-bindings/audiocore/WaveFile.h"
+//#include "shared-bindings/audiomixer/Mixer.h"
//| :mod:`audiocore` --- Support for audio samples and mixer
//| ========================================================
@@ -49,15 +49,13 @@
//| .. toctree::
//| :maxdepth: 3
//|
-//| Mixer
-//| MixerVoice
//| RawSample
//| WaveFile
//|
STATIC const mp_rom_map_elem_t audiocore_module_globals_table[] = {
{ MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_audiocore) },
- { MP_ROM_QSTR(MP_QSTR_Mixer), MP_ROM_PTR(&audioio_mixer_type) },
+ //{ MP_ROM_QSTR(MP_QSTR_Mixer), MP_ROM_PTR(&audioio_mixer_type) },
{ MP_ROM_QSTR(MP_QSTR_RawSample), MP_ROM_PTR(&audioio_rawsample_type) },
{ MP_ROM_QSTR(MP_QSTR_WaveFile), MP_ROM_PTR(&audioio_wavefile_type) },
};
diff --git a/shared-bindings/audioio/__init__.c b/shared-bindings/audioio/__init__.c
index bd771dda2..0d307335f 100644
--- a/shared-bindings/audioio/__init__.c
+++ b/shared-bindings/audioio/__init__.c
@@ -34,10 +34,13 @@
#include "shared-bindings/audioio/AudioOut.h"
#ifdef CIRCUITPY_AUDIOIO_COMPAT
-#include "shared-bindings/audiocore/Mixer.h"
+#include "shared-bindings/audiomixer/Mixer.h"
#include "shared-bindings/audiocore/RawSample.h"
#include "shared-bindings/audiocore/WaveFile.h"
#endif
+#ifdef CIRCUIPY_AUDIOMIXER
+#include "shared-bindings/audiomixer/Mixer.h"
+#endif
//| :mod:`audioio` --- Support for audio input and output
//| ======================================================
@@ -72,7 +75,7 @@ STATIC const mp_rom_map_elem_t audioio_module_globals_table[] = {
{ MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_audioio) },
{ MP_ROM_QSTR(MP_QSTR_AudioOut), MP_ROM_PTR(&audioio_audioout_type) },
#ifdef CIRCUITPY_AUDIOIO_COMPAT
- { MP_ROM_QSTR(MP_QSTR_Mixer), MP_ROM_PTR(&audioio_mixer_type) },
+ //{ MP_ROM_QSTR(MP_QSTR_Mixer), MP_ROM_PTR(&audiomixer_mixer_type) },
{ MP_ROM_QSTR(MP_QSTR_RawSample), MP_ROM_PTR(&audioio_rawsample_type) },
{ MP_ROM_QSTR(MP_QSTR_WaveFile), MP_ROM_PTR(&audioio_wavefile_type) },
#endif
diff --git a/shared-bindings/audiocore/Mixer.h b/shared-bindings/audiomixer/Mixer.h
index 87d681ce6..9eabbf61d 100644
--- a/shared-bindings/audiocore/Mixer.h
+++ b/shared-bindings/audiomixer/Mixer.h
@@ -24,28 +24,28 @@
* THE SOFTWARE.
*/
-#ifndef MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOIO_MIXER_H
-#define MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOIO_MIXER_H
+#ifndef MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER_MIXER_H
+#define MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER_MIXER_H
#include "common-hal/microcontroller/Pin.h"
-#include "shared-module/audiocore/Mixer.h"
+#include "shared-module/audiomixer/Mixer.h"
#include "shared-bindings/audiocore/RawSample.h"
-extern const mp_obj_type_t audioio_mixer_type;
-extern const mp_obj_type_t audioio_mixervoice_type;
+extern const mp_obj_type_t audiomixer_mixer_type;
+extern const mp_obj_type_t audiomixer_mixervoice_type;
-void common_hal_audioio_mixer_construct(audioio_mixer_obj_t* self,
- uint8_t voice_count,
- uint32_t buffer_size,
- uint8_t bits_per_sample,
- bool samples_signed,
- uint8_t channel_count,
- uint32_t sample_rate);
+void common_hal_audiomixer_mixer_construct(audiomixer_mixer_obj_t* self,
+ uint8_t voice_count,
+ uint32_t buffer_size,
+ uint8_t bits_per_sample,
+ bool samples_signed,
+ uint8_t channel_count,
+ uint32_t sample_rate);
-void common_hal_audioio_mixer_deinit(audioio_mixer_obj_t* self);
-bool common_hal_audioio_mixer_deinited(audioio_mixer_obj_t* self);
+void common_hal_audiomixer_mixer_deinit(audiomixer_mixer_obj_t* self);
+bool common_hal_audiomixer_mixer_deinited(audiomixer_mixer_obj_t* self);
-bool common_hal_audioio_mixer_get_playing(audioio_mixer_obj_t* self);
-uint32_t common_hal_audioio_mixer_get_sample_rate(audioio_mixer_obj_t* self);
+bool common_hal_audiomixer_mixer_get_playing(audiomixer_mixer_obj_t* self);
+uint32_t common_hal_audiomixer_mixer_get_sample_rate(audiomixer_mixer_obj_t* self);
-#endif // MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOIO_MIXER_H
+#endif // MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER_MIXER_H
diff --git a/shared-bindings/audiocore/MixerVoice.c b/shared-bindings/audiomixer/MixerVoice.c
index d666c235c..5c082d931 100644
--- a/shared-bindings/audiocore/MixerVoice.c
+++ b/shared-bindings/audiomixer/MixerVoice.c
@@ -23,8 +23,8 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/
-#include "shared-bindings/audiocore/Mixer.h"
-#include "shared-bindings/audiocore/MixerVoice.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+#include "shared-bindings/audiomixer/MixerVoice.h"
#include <stdint.h>
@@ -37,7 +37,7 @@
#include "shared-bindings/util.h"
#include "supervisor/shared/translate.h"
-//| .. currentmodule:: audiocore
+//| .. currentmodule:: audiomixer
//|
//| :class:`MixerVoice` -- Voice objects used with Mixer
//| =====================================================
@@ -46,14 +46,14 @@
//|
//| .. class:: MixerVoice()
//|
-//| MixerVoice instance object(s) created by `audiocore.Mixer`.
+//| MixerVoice instance object(s) created by `audiomixer.Mixer`.
//|
// TODO: support mono or stereo voices
-STATIC mp_obj_t audioio_mixervoice_make_new(const mp_obj_type_t *type, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
- audioio_mixervoice_obj_t *self = m_new_obj(audioio_mixervoice_obj_t);
- self->base.type = &audioio_mixervoice_type;
+STATIC mp_obj_t audiomixer_mixervoice_make_new(const mp_obj_type_t *type, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+ audiomixer_mixervoice_obj_t *self = m_new_obj(audiomixer_mixervoice_obj_t);
+ self->base.type = &audiomixer_mixervoice_type;
- common_hal_audioio_mixervoice_construct(self);
+ common_hal_audiomixer_mixervoice_construct(self);
return MP_OBJ_FROM_PTR(self);
}
@@ -67,56 +67,56 @@ STATIC mp_obj_t audioio_mixervoice_make_new(const mp_obj_type_t *type, size_t n_
//|
//| The sample must match the `audiocore.Mixer`'s encoding settings given in the constructor.
//|
-STATIC mp_obj_t audioio_mixervoice_obj_play(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+STATIC mp_obj_t audiomixer_mixervoice_obj_play(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
enum { ARG_sample, ARG_loop };
static const mp_arg_t allowed_args[] = {
{ MP_QSTR_sample, MP_ARG_OBJ | MP_ARG_REQUIRED },
{ MP_QSTR_loop, MP_ARG_BOOL | MP_ARG_KW_ONLY, {.u_bool = false} },
};
- audioio_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
+ audiomixer_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
mp_arg_val_t args[MP_ARRAY_SIZE(allowed_args)];
mp_arg_parse_all(n_args - 1, pos_args + 1, kw_args, MP_ARRAY_SIZE(allowed_args), allowed_args, args);
mp_obj_t sample = args[ARG_sample].u_obj;
- common_hal_audioio_mixervoice_play(self, sample, args[ARG_loop].u_bool);
+ common_hal_audiomixer_mixervoice_play(self, sample, args[ARG_loop].u_bool);
return mp_const_none;
}
-MP_DEFINE_CONST_FUN_OBJ_KW(audioio_mixervoice_play_obj, 1, audioio_mixervoice_obj_play);
+MP_DEFINE_CONST_FUN_OBJ_KW(audiomixer_mixervoice_play_obj, 1, audiomixer_mixervoice_obj_play);
//| .. method:: stop()
//|
//| Stops playback of the sample on this voice.
//|
-STATIC mp_obj_t audioio_mixervoice_obj_stop(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+STATIC mp_obj_t audiomixer_mixervoice_obj_stop(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
enum { ARG_voice };
static const mp_arg_t allowed_args[] = {
{ MP_QSTR_voice, MP_ARG_INT, {.u_int = 0} },
};
- audioio_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
+ audiomixer_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
mp_arg_val_t args[MP_ARRAY_SIZE(allowed_args)];
mp_arg_parse_all(n_args - 1, pos_args + 1, kw_args, MP_ARRAY_SIZE(allowed_args), allowed_args, args);
- common_hal_audioio_mixervoice_stop(self);
+ common_hal_audiomixer_mixervoice_stop(self);
return mp_const_none;
}
-MP_DEFINE_CONST_FUN_OBJ_KW(audioio_mixervoice_stop_obj, 1, audioio_mixervoice_obj_stop);
+MP_DEFINE_CONST_FUN_OBJ_KW(audiomixer_mixervoice_stop_obj, 1, audiomixer_mixervoice_obj_stop);
//| .. attribute:: level()
//|
//| The volume level of a voice, as a floating point number between 0 and 1.
//|
-STATIC mp_obj_t audioio_mixervoice_obj_get_level(mp_obj_t self_in) {
- return mp_obj_new_float(common_hal_audioio_mixervoice_get_level(self_in));
+STATIC mp_obj_t audiomixer_mixervoice_obj_get_level(mp_obj_t self_in) {
+ return mp_obj_new_float(common_hal_audiomixer_mixervoice_get_level(self_in));
}
-MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixervoice_get_level_obj, audioio_mixervoice_obj_get_level);
+MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixervoice_get_level_obj, audiomixer_mixervoice_obj_get_level);
-STATIC mp_obj_t audioio_mixervoice_obj_set_level(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+STATIC mp_obj_t audiomixer_mixervoice_obj_set_level(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
enum { ARG_level };
static const mp_arg_t allowed_args[] = {
{ MP_QSTR_level, MP_ARG_OBJ | MP_ARG_REQUIRED },
};
- audioio_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
+ audiomixer_mixervoice_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
mp_arg_val_t args[MP_ARRAY_SIZE(allowed_args)];
mp_arg_parse_all(n_args - 1, pos_args + 1, kw_args, MP_ARRAY_SIZE(allowed_args), allowed_args, args);
@@ -126,16 +126,16 @@ STATIC mp_obj_t audioio_mixervoice_obj_set_level(size_t n_args, const mp_obj_t *
mp_raise_ValueError(translate("level must be between 0 and 1"));
}
- common_hal_audioio_mixervoice_set_level(self, level);
+ common_hal_audiomixer_mixervoice_set_level(self, level);
return mp_const_none;
}
-MP_DEFINE_CONST_FUN_OBJ_KW(audioio_mixervoice_set_level_obj, 1, audioio_mixervoice_obj_set_level);
+MP_DEFINE_CONST_FUN_OBJ_KW(audiomixer_mixervoice_set_level_obj, 1, audiomixer_mixervoice_obj_set_level);
-const mp_obj_property_t audioio_mixervoice_level_obj = {
+const mp_obj_property_t audiomixer_mixervoice_level_obj = {
.base.type = &mp_type_property,
- .proxy = {(mp_obj_t)&audioio_mixervoice_get_level_obj,
- (mp_obj_t)&audioio_mixervoice_set_level_obj,
+ .proxy = {(mp_obj_t)&audiomixer_mixervoice_get_level_obj,
+ (mp_obj_t)&audiomixer_mixervoice_set_level_obj,
(mp_obj_t)&mp_const_none_obj},
};
@@ -144,35 +144,35 @@ const mp_obj_property_t audioio_mixervoice_level_obj = {
//| True when any voice is being output. (read-only)
//|
-STATIC mp_obj_t audioio_mixervoice_obj_get_playing(mp_obj_t self_in) {
- audioio_mixervoice_obj_t *self = MP_OBJ_TO_PTR(self_in);
+STATIC mp_obj_t audiomixer_mixervoice_obj_get_playing(mp_obj_t self_in) {
+ audiomixer_mixervoice_obj_t *self = MP_OBJ_TO_PTR(self_in);
- return mp_obj_new_bool(common_hal_audioio_mixervoice_get_playing(self));
+ return mp_obj_new_bool(common_hal_audiomixer_mixervoice_get_playing(self));
}
-MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixervoice_get_playing_obj, audioio_mixervoice_obj_get_playing);
+MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixervoice_get_playing_obj, audiomixer_mixervoice_obj_get_playing);
-const mp_obj_property_t audioio_mixervoice_playing_obj = {
+const mp_obj_property_t audiomixer_mixervoice_playing_obj = {
.base.type = &mp_type_property,
- .proxy = {(mp_obj_t)&audioio_mixervoice_get_playing_obj,
+ .proxy = {(mp_obj_t)&audiomixer_mixervoice_get_playing_obj,
(mp_obj_t)&mp_const_none_obj,
(mp_obj_t)&mp_const_none_obj},
};
-STATIC const mp_rom_map_elem_t audioio_mixervoice_locals_dict_table[] = {
+STATIC const mp_rom_map_elem_t audiomixer_mixervoice_locals_dict_table[] = {
// Methods
- { MP_ROM_QSTR(MP_QSTR_play), MP_ROM_PTR(&audioio_mixervoice_play_obj) },
- { MP_ROM_QSTR(MP_QSTR_stop), MP_ROM_PTR(&audioio_mixervoice_stop_obj) },
+ { MP_ROM_QSTR(MP_QSTR_play), MP_ROM_PTR(&audiomixer_mixervoice_play_obj) },
+ { MP_ROM_QSTR(MP_QSTR_stop), MP_ROM_PTR(&audiomixer_mixervoice_stop_obj) },
// Properties
- { MP_ROM_QSTR(MP_QSTR_playing), MP_ROM_PTR(&audioio_mixervoice_playing_obj) },
- { MP_ROM_QSTR(MP_QSTR_level), MP_ROM_PTR(&audioio_mixervoice_level_obj) },
+ { MP_ROM_QSTR(MP_QSTR_playing), MP_ROM_PTR(&audiomixer_mixervoice_playing_obj) },
+ { MP_ROM_QSTR(MP_QSTR_level), MP_ROM_PTR(&audiomixer_mixervoice_level_obj) },
};
-STATIC MP_DEFINE_CONST_DICT(audioio_mixervoice_locals_dict, audioio_mixervoice_locals_dict_table);
+STATIC MP_DEFINE_CONST_DICT(audiomixer_mixervoice_locals_dict, audiomixer_mixervoice_locals_dict_table);
-const mp_obj_type_t audioio_mixervoice_type = {
+const mp_obj_type_t audiomixer_mixervoice_type = {
{ &mp_type_type },
.name = MP_QSTR_MixerVoice,
- .make_new = audioio_mixervoice_make_new,
- .locals_dict = (mp_obj_dict_t*)&audioio_mixervoice_locals_dict,
+ .make_new = audiomixer_mixervoice_make_new,
+ .locals_dict = (mp_obj_dict_t*)&audiomixer_mixervoice_locals_dict,
};
diff --git a/shared-bindings/audiocore/MixerVoice.h b/shared-bindings/audiomixer/MixerVoice.h
index 5849ce252..83098bc9d 100644
--- a/shared-bindings/audiocore/MixerVoice.h
+++ b/shared-bindings/audiomixer/MixerVoice.h
@@ -23,25 +23,25 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/
-#ifndef SHARED_BINDINGS_AUDIOIO_MIXERVOICE_H_
-#define SHARED_BINDINGS_AUDIOIO_MIXERVOICE_H_
+#ifndef SHARED_BINDINGS_AUDIOMIXER_MIXERVOICE_H_
+#define SHARED_BINDINGS_AUDIOMIXER_MIXERVOICE_H_
#include "common-hal/microcontroller/Pin.h"
-#include "shared-module/audiocore/Mixer.h"
#include "shared-bindings/audiocore/RawSample.h"
-#include "shared-module/audiocore/MixerVoice.h"
-#include "shared-module/audiocore/Mixer.h"
-extern const mp_obj_type_t audioio_mixer_type;
-extern const mp_obj_type_t audioio_mixervoice_type;
+#include "shared-module/audiomixer/MixerVoice.h"
+#include "shared-module/audiomixer/Mixer.h"
-void common_hal_audioio_mixervoice_construct(audioio_mixervoice_obj_t *self);
-void common_hal_audioio_mixervoice_set_parent(audioio_mixervoice_obj_t* self, audioio_mixer_obj_t *parent);
-void common_hal_audioio_mixervoice_play(audioio_mixervoice_obj_t* self, mp_obj_t sample, bool loop);
-void common_hal_audioio_mixervoice_stop(audioio_mixervoice_obj_t* self);
-float common_hal_audioio_mixervoice_get_level(audioio_mixervoice_obj_t* self);
-void common_hal_audioio_mixervoice_set_level(audioio_mixervoice_obj_t* self, float gain);
+extern const mp_obj_type_t audiomixer_mixer_type;
+extern const mp_obj_type_t audiomixer_mixervoice_type;
-bool common_hal_audioio_mixervoice_get_playing(audioio_mixervoice_obj_t* self);
+void common_hal_audiomixer_mixervoice_construct(audiomixer_mixervoice_obj_t *self);
+void common_hal_audiomixer_mixervoice_set_parent(audiomixer_mixervoice_obj_t* self, audiomixer_mixer_obj_t *parent);
+void common_hal_audiomixer_mixervoice_play(audiomixer_mixervoice_obj_t* self, mp_obj_t sample, bool loop);
+void common_hal_audiomixer_mixervoice_stop(audiomixer_mixervoice_obj_t* self);
+float common_hal_audiomixer_mixervoice_get_level(audiomixer_mixervoice_obj_t* self);
+void common_hal_audiomixer_mixervoice_set_level(audiomixer_mixervoice_obj_t* self, float gain);
-#endif /* SHARED_BINDINGS_AUDIOIO_MIXERVOICE_H_ */
+bool common_hal_audiomixer_mixervoice_get_playing(audiomixer_mixervoice_obj_t* self);
+
+#endif /* SHARED_BINDINGS_AUDIOMIXER_MIXERVOICE_H_ */
diff --git a/shared-bindings/audiomixer/__init__.c b/shared-bindings/audiomixer/__init__.c
new file mode 100644
index 000000000..a8dd4309f
--- /dev/null
+++ b/shared-bindings/audiomixer/__init__.c
@@ -0,0 +1,63 @@
+/*
+ * This file is part of the MicroPython project, http://micropython.org/
+ *
+ * The MIT License (MIT)
+ *
+ * Copyright (c) 2019 Michael Schroeder
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
+
+#include <stdint.h>
+
+#include "py/obj.h"
+#include "py/runtime.h"
+
+#include "shared-bindings/microcontroller/Pin.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+
+//| :mod:`audiomixer` --- Support for audio mixer
+//| ========================================================
+//|
+//| .. module:: audiomixer
+//| :synopsis: Support for audio mixer
+//| :platform: SAMD21
+//|
+//| The `audiomixer` module contains core classes for mixing audio sources
+//|
+//| Libraries
+//|
+//| .. toctree::
+//| :maxdepth: 3
+//|
+//| Mixer
+//| MixerVoice
+//|
+
+STATIC const mp_rom_map_elem_t audiomixer_module_globals_table[] = {
+ { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_audiomixer) },
+ { MP_ROM_QSTR(MP_QSTR_Mixer), MP_ROM_PTR(&audiomixer_mixer_type) },
+};
+
+STATIC MP_DEFINE_CONST_DICT(audiomixer_module_globals, audiomixer_module_globals_table);
+
+const mp_obj_module_t audiomixer_module = {
+ .base = { &mp_type_module },
+ .globals = (mp_obj_dict_t*)&audiomixer_module_globals,
+};
diff --git a/shared-bindings/audiomixer/__init__.h b/shared-bindings/audiomixer/__init__.h
new file mode 100644
index 000000000..35a90441c
--- /dev/null
+++ b/shared-bindings/audiomixer/__init__.h
@@ -0,0 +1,34 @@
+/*
+ * This file is part of the MicroPython project, http://micropython.org/
+ *
+ * The MIT License (MIT)
+ *
+ * Copyright (c) 2019 Michael Schroeder
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
+
+#ifndef MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER___INIT___H
+#define MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER___INIT___H
+
+#include "py/obj.h"
+
+// Nothing now.
+
+#endif // MICROPY_INCLUDED_SHARED_BINDINGS_AUDIOMIXER___INIT___H
diff --git a/shared-module/audiocore/__init__.c b/shared-module/audiocore/__init__.c
index 067cae5dd..8433a1770 100644
--- a/shared-module/audiocore/__init__.c
+++ b/shared-module/audiocore/__init__.c
@@ -27,13 +27,14 @@
#include "shared-module/audioio/__init__.h"
#include "py/obj.h"
-#include "shared-bindings/audiocore/Mixer.h"
#include "shared-bindings/audiocore/RawSample.h"
#include "shared-bindings/audiocore/WaveFile.h"
-#include "shared-module/audiocore/Mixer.h"
#include "shared-module/audiocore/RawSample.h"
#include "shared-module/audiocore/WaveFile.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+#include "shared-module/audiomixer/Mixer.h"
+
uint32_t audiosample_sample_rate(mp_obj_t sample_obj) {
if (MP_OBJ_IS_TYPE(sample_obj, &audioio_rawsample_type)) {
audioio_rawsample_obj_t* sample = MP_OBJ_TO_PTR(sample_obj);
@@ -41,8 +42,8 @@ uint32_t audiosample_sample_rate(mp_obj_t sample_obj) {
} else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_wavefile_type)) {
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
return file->sample_rate;
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
return mixer->sample_rate;
}
return 16000;
@@ -55,8 +56,8 @@ uint8_t audiosample_bits_per_sample(mp_obj_t sample_obj) {
} else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_wavefile_type)) {
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
return file->bits_per_sample;
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
return mixer->bits_per_sample;
}
return 8;
@@ -69,8 +70,8 @@ uint8_t audiosample_channel_count(mp_obj_t sample_obj) {
} else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_wavefile_type)) {
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
return file->channel_count;
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* mixer = MP_OBJ_TO_PTR(sample_obj);
return mixer->channel_count;
}
return 1;
@@ -83,9 +84,9 @@ void audiosample_reset_buffer(mp_obj_t sample_obj, bool single_channel, uint8_t
} else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_wavefile_type)) {
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
audioio_wavefile_reset_buffer(file, single_channel, audio_channel);
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
- audioio_mixer_reset_buffer(file, single_channel, audio_channel);
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
+ audiomixer_mixer_reset_buffer(file, single_channel, audio_channel);
}
}
@@ -99,9 +100,9 @@ audioio_get_buffer_result_t audiosample_get_buffer(mp_obj_t sample_obj,
} else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_wavefile_type)) {
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
return audioio_wavefile_get_buffer(file, single_channel, channel, buffer, buffer_length);
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
- return audioio_mixer_get_buffer(file, single_channel, channel, buffer, buffer_length);
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
+ return audiomixer_mixer_get_buffer(file, single_channel, channel, buffer, buffer_length);
}
return GET_BUFFER_DONE;
}
@@ -117,9 +118,9 @@ void audiosample_get_buffer_structure(mp_obj_t sample_obj, bool single_channel,
audioio_wavefile_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
audioio_wavefile_get_buffer_structure(file, single_channel, single_buffer, samples_signed,
max_buffer_length, spacing);
- } else if (MP_OBJ_IS_TYPE(sample_obj, &audioio_mixer_type)) {
- audioio_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
- audioio_mixer_get_buffer_structure(file, single_channel, single_buffer, samples_signed,
+ } else if (MP_OBJ_IS_TYPE(sample_obj, &audiomixer_mixer_type)) {
+ audiomixer_mixer_obj_t* file = MP_OBJ_TO_PTR(sample_obj);
+ audiomixer_mixer_get_buffer_structure(file, single_channel, single_buffer, samples_signed,
max_buffer_length, spacing);
}
}
diff --git a/shared-module/audiocore/Mixer.c b/shared-module/audiomixer/Mixer.c
index c372d68d0..0ae7c7b09 100644
--- a/shared-module/audiocore/Mixer.c
+++ b/shared-module/audiomixer/Mixer.c
@@ -26,8 +26,8 @@
* THE SOFTWARE.
*/
-#include "shared-bindings/audiocore/Mixer.h"
-#include "shared-bindings/audiocore/MixerVoice.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+#include "shared-bindings/audiomixer/MixerVoice.h"
#include <stdint.h>
@@ -35,24 +35,24 @@
#include "shared-module/audiocore/__init__.h"
#include "shared-module/audiocore/RawSample.h"
-void common_hal_audioio_mixer_construct(audioio_mixer_obj_t* self,
- uint8_t voice_count,
- uint32_t buffer_size,
- uint8_t bits_per_sample,
- bool samples_signed,
- uint8_t channel_count,
- uint32_t sample_rate) {
+void common_hal_audiomixer_mixer_construct(audiomixer_mixer_obj_t* self,
+ uint8_t voice_count,
+ uint32_t buffer_size,
+ uint8_t bits_per_sample,
+ bool samples_signed,
+ uint8_t channel_count,
+ uint32_t sample_rate) {
self->len = buffer_size / 2 / sizeof(uint32_t) * sizeof(uint32_t);
self->first_buffer = m_malloc(self->len, false);
if (self->first_buffer == NULL) {
- common_hal_audioio_mixer_deinit(self);
+ common_hal_audiomixer_mixer_deinit(self);
mp_raise_msg(&mp_type_MemoryError, translate("Couldn't allocate first buffer"));
}
self->second_buffer = m_malloc(self->len, false);
if (self->second_buffer == NULL) {
- common_hal_audioio_mixer_deinit(self);
+ common_hal_audiomixer_mixer_deinit(self);
mp_raise_msg(&mp_type_MemoryError, translate("Couldn't allocate second buffer"));
}
@@ -63,31 +63,31 @@ void common_hal_audioio_mixer_construct(audioio_mixer_obj_t* self,
self->voice_count = voice_count;
}
-void common_hal_audioio_mixer_deinit(audioio_mixer_obj_t* self) {
+void common_hal_audiomixer_mixer_deinit(audiomixer_mixer_obj_t* self) {
self->first_buffer = NULL;
self->second_buffer = NULL;
}
-bool common_hal_audioio_mixer_deinited(audioio_mixer_obj_t* self) {
+bool common_hal_audiomixer_mixer_deinited(audiomixer_mixer_obj_t* self) {
return self->first_buffer == NULL;
}
-uint32_t common_hal_audioio_mixer_get_sample_rate(audioio_mixer_obj_t* self) {
+uint32_t common_hal_audiomixer_mixer_get_sample_rate(audiomixer_mixer_obj_t* self) {
return self->sample_rate;
}
-bool common_hal_audioio_mixer_get_playing(audioio_mixer_obj_t* self) {
+bool common_hal_audiomixer_mixer_get_playing(audiomixer_mixer_obj_t* self) {
for (int32_t v = 0; v < self->voice_count; v++) {
- if (common_hal_audioio_mixervoice_get_playing(MP_OBJ_TO_PTR(self->voice[v]))) {
+ if (common_hal_audiomixer_mixervoice_get_playing(MP_OBJ_TO_PTR(self->voice[v]))) {
return true;
}
}
return false;
}
-void audioio_mixer_reset_buffer(audioio_mixer_obj_t* self,
- bool single_channel,
- uint8_t channel) {
+void audiomixer_mixer_reset_buffer(audiomixer_mixer_obj_t* self,
+ bool single_channel,
+ uint8_t channel) {
#if 0
for (int32_t i = 0; i < self->voice_count; i++) {
self->voice[i].sample = NULL;
@@ -289,11 +289,11 @@ static inline uint32_t mult16signed(uint32_t val, int32_t mul) {
#endif
}
-audioio_get_buffer_result_t audioio_mixer_get_buffer(audioio_mixer_obj_t* self,
- bool single_channel,
- uint8_t channel,
- uint8_t** buffer,
- uint32_t* buffer_length) {
+audioio_get_buffer_result_t audiomixer_mixer_get_buffer(audiomixer_mixer_obj_t* self,
+ bool single_channel,
+ uint8_t channel,
+ uint8_t** buffer,
+ uint32_t* buffer_length) {
if (!single_channel) {
channel = 0;
}
@@ -317,7 +317,7 @@ audioio_get_buffer_result_t audioio_mixer_get_buffer(audioio_mixer_obj_t* self,
self->use_first_buffer = !self->use_first_buffer;
bool voices_active = false;
for (int32_t v = 0; v < self->voice_count; v++) {
- audioio_mixervoice_obj_t* voice = MP_OBJ_TO_PTR(self->voice[v]);
+ audiomixer_mixervoice_obj_t* voice = MP_OBJ_TO_PTR(self->voice[v]);
uint32_t j = 0;
bool voice_done = voice->sample == NULL;
@@ -416,7 +416,7 @@ audioio_get_buffer_result_t audioio_mixer_get_buffer(audioio_mixer_obj_t* self,
return GET_BUFFER_MORE_DATA;
}
-void audioio_mixer_get_buffer_structure(audioio_mixer_obj_t* self, bool single_channel,
+void audiomixer_mixer_get_buffer_structure(audiomixer_mixer_obj_t* self, bool single_channel,
bool* single_buffer, bool* samples_signed,
uint32_t* max_buffer_length, uint8_t* spacing) {
*single_buffer = false;
diff --git a/shared-module/audiocore/Mixer.h b/shared-module/audiomixer/Mixer.h
index aaab60e84..ab4780efc 100644
--- a/shared-module/audiocore/Mixer.h
+++ b/shared-module/audiomixer/Mixer.h
@@ -24,8 +24,8 @@
* THE SOFTWARE.
*/
-#ifndef MICROPY_INCLUDED_SHARED_MODULE_AUDIOIO_MIXER_H
-#define MICROPY_INCLUDED_SHARED_MODULE_AUDIOIO_MIXER_H
+#ifndef MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER_MIXER_H
+#define MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER_MIXER_H
#include "py/obj.h"
#include "py/objtuple.h"
@@ -50,20 +50,20 @@ typedef struct {
uint8_t voice_count;
mp_obj_tuple_t *voice_tuple;
mp_obj_t voice[];
-} audioio_mixer_obj_t;
+} audiomixer_mixer_obj_t;
// These are not available from Python because it may be called in an interrupt.
-void audioio_mixer_reset_buffer(audioio_mixer_obj_t* self,
+void audiomixer_mixer_reset_buffer(audiomixer_mixer_obj_t* self,
bool single_channel,
uint8_t channel);
-audioio_get_buffer_result_t audioio_mixer_get_buffer(audioio_mixer_obj_t* self,
+audioio_get_buffer_result_t audiomixer_mixer_get_buffer(audiomixer_mixer_obj_t* self,
bool single_channel,
uint8_t channel,
uint8_t** buffer,
uint32_t* buffer_length); // length in bytes
-void audioio_mixer_get_buffer_structure(audioio_mixer_obj_t* self, bool single_channel,
+void audiomixer_mixer_get_buffer_structure(audiomixer_mixer_obj_t* self, bool single_channel,
bool* single_buffer, bool* samples_signed,
uint32_t* max_buffer_length, uint8_t* spacing);
-#endif // MICROPY_INCLUDED_SHARED_MODULE_AUDIOIO_MIXER_H
+#endif // MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER_MIXER_H
diff --git a/shared-module/audiocore/MixerVoice.c b/shared-module/audiomixer/MixerVoice.c
index 80c07511e..ff05dc93e 100644
--- a/shared-module/audiocore/MixerVoice.c
+++ b/shared-module/audiomixer/MixerVoice.c
@@ -23,33 +23,33 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/
-#include "shared-bindings/audiocore/Mixer.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+#include "shared-module/audiomixer/MixerVoice.h"
#include <stdint.h>
#include "py/runtime.h"
-#include "shared-module/audioio/__init__.h"
+#include "shared-module/audiomixer/__init__.h"
#include "shared-module/audiocore/RawSample.h"
-#include "shared-module/audiocore/MixerVoice.h"
-void common_hal_audioio_mixervoice_construct(audioio_mixervoice_obj_t *self) {
+void common_hal_audiomixer_mixervoice_construct(audiomixer_mixervoice_obj_t *self) {
self->sample = NULL;
self->level = ((1 << 15) - 1);
}
-void common_hal_audioio_mixervoice_set_parent(audioio_mixervoice_obj_t* self, audioio_mixer_obj_t *parent) {
+void common_hal_audiomixer_mixervoice_set_parent(audiomixer_mixervoice_obj_t* self, audiomixer_mixer_obj_t *parent) {
self->parent = parent;
}
-float common_hal_audioio_mixervoice_get_level(audioio_mixervoice_obj_t* self) {
+float common_hal_audiomixer_mixervoice_get_level(audiomixer_mixervoice_obj_t* self) {
return ((float) self->level / ((1 << 15) - 1));
}
-void common_hal_audioio_mixervoice_set_level(audioio_mixervoice_obj_t* self, float level) {
+void common_hal_audiomixer_mixervoice_set_level(audiomixer_mixervoice_obj_t* self, float level) {
self->level = level * ((1 << 15)-1);
}
-void common_hal_audioio_mixervoice_play(audioio_mixervoice_obj_t* self, mp_obj_t sample, bool loop) {
+void common_hal_audiomixer_mixervoice_play(audiomixer_mixervoice_obj_t* self, mp_obj_t sample, bool loop) {
if (audiosample_sample_rate(sample) != self->parent->sample_rate) {
mp_raise_ValueError(translate("The sample's sample rate does not match the mixer's"));
}
@@ -78,10 +78,10 @@ void common_hal_audioio_mixervoice_play(audioio_mixervoice_obj_t* self, mp_obj_t
self->more_data = result == GET_BUFFER_MORE_DATA;
}
-bool common_hal_audioio_mixervoice_get_playing(audioio_mixervoice_obj_t* self) {
+bool common_hal_audiomixer_mixervoice_get_playing(audiomixer_mixervoice_obj_t* self) {
return self->sample != NULL;
}
-void common_hal_audioio_mixervoice_stop(audioio_mixervoice_obj_t* self) {
+void common_hal_audiomixer_mixervoice_stop(audiomixer_mixervoice_obj_t* self) {
self->sample = NULL;
}
diff --git a/shared-module/audiocore/MixerVoice.h b/shared-module/audiomixer/MixerVoice.h
index 6010313bf..efac19156 100644
--- a/shared-module/audiocore/MixerVoice.h
+++ b/shared-module/audiomixer/MixerVoice.h
@@ -23,24 +23,24 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/
-#ifndef SHARED_MODULE_AUDIOIO_MIXERVOICE_H_
-#define SHARED_MODULE_AUDIOIO_MIXERVOICE_H_
+#ifndef SHARED_MODULE_AUDIOMIXER_MIXERVOICE_H_
+#define SHARED_MODULE_AUDIOMIXER_MIXERVOICE_H_
#include "py/obj.h"
-#include "shared-module/audiocore/__init__.h"
-#include "shared-module/audiocore/Mixer.h"
+#include "shared-module/audiomixer/__init__.h"
+#include "shared-module/audiomixer/Mixer.h"
typedef struct {
mp_obj_base_t base;
- audioio_mixer_obj_t *parent;
+ audiomixer_mixer_obj_t *parent;
mp_obj_t sample;
bool loop;
bool more_data;
uint32_t* remaining_buffer;
uint32_t buffer_length;
int16_t level;
-} audioio_mixervoice_obj_t;
+} audiomixer_mixervoice_obj_t;
-#endif /* SHARED_MODULE_AUDIOIO_MIXERVOICE_H_ */
+#endif /* SHARED_MODULE_AUDIOMIXER_MIXERVOICE_H_ */
diff --git a/shared-module/audiomixer/__init__.c b/shared-module/audiomixer/__init__.c
new file mode 100644
index 000000000..e69de29bb
--- /dev/null
+++ b/shared-module/audiomixer/__init__.c
diff --git a/shared-module/audiomixer/__init__.h b/shared-module/audiomixer/__init__.h
new file mode 100644
index 000000000..35b731558
--- /dev/null
+++ b/shared-module/audiomixer/__init__.h
@@ -0,0 +1,32 @@
+/*
+ * This file is part of the MicroPython project, http://micropython.org/
+ *
+ * The MIT License (MIT)
+ *
+ * Copyright (c) 2018 Dan Halbert for Adafruit Industries
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
+
+#ifndef MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER__INIT__H
+#define MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER__INIT__H
+
+#include "shared-module/audiocore/__init__.h"
+
+#endif // MICROPY_INCLUDED_SHARED_MODULE_AUDIOMIXER__INIT__H
diff --git a/shared-bindings/audiocore/Mixer.c b/shared-bindings/audiomixer/Mixer.c
index 59ff5eea7..3beb61118 100644
--- a/shared-bindings/audiocore/Mixer.c
+++ b/shared-bindings/audiomixer/Mixer.c
@@ -23,9 +23,9 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/
-#include "shared-bindings/audiocore/Mixer.h"
-#include "shared-bindings/audiocore/MixerVoice.h"
-#include "shared-module/audiocore/MixerVoice.h"
+#include "shared-bindings/audiomixer/Mixer.h"
+#include "shared-bindings/audiomixer/MixerVoice.h"
+#include "shared-module/audiomixer/MixerVoice.h"
#include <stdint.h>
@@ -38,7 +38,7 @@
#include "shared-bindings/util.h"
#include "supervisor/shared/translate.h"
-//| .. currentmodule:: audiocore
+//| .. currentmodule:: audiomixer
//|
//| :class:`Mixer` -- Mixes one or more audio samples together
//| ===========================================================
@@ -62,6 +62,7 @@
//| import board
//| import audioio
//| import audiocore
+//| import audiomixer
//| import digitalio
//|
//| # Required for CircuitPlayground Express
@@ -70,8 +71,8 @@
//|
//| music = audiocore.WaveFile(open("cplay-5.1-16bit-16khz.wav", "rb"))
//| drum = audiocore.WaveFile(open("drum.wav", "rb"))
-//| mixer = audiocore.Mixer(voice_count=2, sample_rate=16000, channel_count=1,
-//| bits_per_sample=16, samples_signed=True)
+//| mixer = audiomixer.Mixer(voice_count=2, sample_rate=16000, channel_count=1,
+//| bits_per_sample=16, samples_signed=True)
//| a = audioio.AudioOut(board.A0)
//|
//| print("playing")
@@ -85,7 +86,7 @@
//| time.sleep(1)
//| print("stopped")
//|
-STATIC mp_obj_t audioio_mixer_make_new(const mp_obj_type_t *type, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+STATIC mp_obj_t audiomixer_mixer_make_new(const mp_obj_type_t *type, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
enum { ARG_voice_count, ARG_buffer_size, ARG_channel_count, ARG_bits_per_sample, ARG_samples_signed, ARG_sample_rate };
static const mp_arg_t allowed_args[] = {
{ MP_QSTR_voice_count, MP_ARG_INT | MP_ARG_KW_ONLY, {.u_int = 2} },
@@ -115,13 +116,13 @@ STATIC mp_obj_t audioio_mixer_make_new(const mp_obj_type_t *type, size_t n_args,
if (bits_per_sample != 8 && bits_per_sample != 16) {
mp_raise_ValueError(translate("bits_per_sample must be 8 or 16"));
}
- audioio_mixer_obj_t *self = m_new_obj_var(audioio_mixer_obj_t, mp_obj_t, voice_count);
- self->base.type = &audioio_mixer_type;
- common_hal_audioio_mixer_construct(self, voice_count, args[ARG_buffer_size].u_int, bits_per_sample, args[ARG_samples_signed].u_bool, channel_count, sample_rate);
+ audiomixer_mixer_obj_t *self = m_new_obj_var(audiomixer_mixer_obj_t, mp_obj_t, voice_count);
+ self->base.type = &audiomixer_mixer_type;
+ common_hal_audiomixer_mixer_construct(self, voice_count, args[ARG_buffer_size].u_int, bits_per_sample, args[ARG_samples_signed].u_bool, channel_count, sample_rate);
for(int v=0; v<voice_count; v++){
- self->voice[v] = audioio_mixervoice_type.make_new(&audioio_mixervoice_type, 0, 0, NULL);
- common_hal_audioio_mixervoice_set_parent(self->voice[v], self);
+ self->voice[v] = audiomixer_mixervoice_type.make_new(&audiomixer_mixervoice_type, 0, 0, NULL);
+ common_hal_audiomixer_mixervoice_set_parent(self->voice[v], self);
}
self->voice_tuple = mp_obj_new_tuple(self->voice_count, self->voice);
@@ -132,15 +133,15 @@ STATIC mp_obj_t audioio_mixer_make_new(const mp_obj_type_t *type, size_t n_args,
//|
//| Deinitialises the Mixer and releases any hardware resources for reuse.
//|
-STATIC mp_obj_t audioio_mixer_deinit(mp_obj_t self_in) {
- audioio_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
- common_hal_audioio_mixer_deinit(self);
+STATIC mp_obj_t audiomixer_mixer_deinit(mp_obj_t self_in) {
+ audiomixer_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
+ common_hal_audiomixer_mixer_deinit(self);
return mp_const_none;
}
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixer_deinit_obj, audioio_mixer_deinit);
+STATIC MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixer_deinit_obj, audiomixer_mixer_deinit);
-STATIC void check_for_deinit(audioio_mixer_obj_t *self) {
- if (common_hal_audioio_mixer_deinited(self)) {
+STATIC void check_for_deinit(audiomixer_mixer_obj_t *self) {
+ if (common_hal_audiomixer_mixer_deinited(self)) {
raise_deinited_error();
}
}
@@ -156,27 +157,27 @@ STATIC void check_for_deinit(audioio_mixer_obj_t *self) {
//| Automatically deinitializes the hardware when exiting a context. See
//| :ref:`lifetime-and-contextmanagers` for more info.
//|
-STATIC mp_obj_t audioio_mixer_obj___exit__(size_t n_args, const mp_obj_t *args) {
+STATIC mp_obj_t audiomixer_mixer_obj___exit__(size_t n_args, const mp_obj_t *args) {
(void)n_args;
- common_hal_audioio_mixer_deinit(args[0]);
+ common_hal_audiomixer_mixer_deinit(args[0]);
return mp_const_none;
}
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(audioio_mixer___exit___obj, 4, 4, audioio_mixer_obj___exit__);
+STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(audiomixer_mixer___exit___obj, 4, 4, audiomixer_mixer_obj___exit__);
//| .. attribute:: playing
//|
//| True when any voice is being output. (read-only)
//|
-STATIC mp_obj_t audioio_mixer_obj_get_playing(mp_obj_t self_in) {
- audioio_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
+STATIC mp_obj_t audiomixer_mixer_obj_get_playing(mp_obj_t self_in) {
+ audiomixer_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
check_for_deinit(self);
- return mp_obj_new_bool(common_hal_audioio_mixer_get_playing(self));
+ return mp_obj_new_bool(common_hal_audiomixer_mixer_get_playing(self));
}
-MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixer_get_playing_obj, audioio_mixer_obj_get_playing);
+MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixer_get_playing_obj, audiomixer_mixer_obj_get_playing);
-const mp_obj_property_t audioio_mixer_playing_obj = {
+const mp_obj_property_t audiomixer_mixer_playing_obj = {
.base.type = &mp_type_property,
- .proxy = {(mp_obj_t)&audioio_mixer_get_playing_obj,
+ .proxy = {(mp_obj_t)&audiomixer_mixer_get_playing_obj,
(mp_obj_t)&mp_const_none_obj,
(mp_obj_t)&mp_const_none_obj},
};
@@ -185,59 +186,59 @@ const mp_obj_property_t audioio_mixer_playing_obj = {
//|
//| 32 bit value that dictates how quickly samples are played in Hertz (cycles per second).
//|
-STATIC mp_obj_t audioio_mixer_obj_get_sample_rate(mp_obj_t self_in) {
- audioio_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
+STATIC mp_obj_t audiomixer_mixer_obj_get_sample_rate(mp_obj_t self_in) {
+ audiomixer_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
check_for_deinit(self);
- return MP_OBJ_NEW_SMALL_INT(common_hal_audioio_mixer_get_sample_rate(self));
+ return MP_OBJ_NEW_SMALL_INT(common_hal_audiomixer_mixer_get_sample_rate(self));
}
-MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixer_get_sample_rate_obj, audioio_mixer_obj_get_sample_rate);
+MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixer_get_sample_rate_obj, audiomixer_mixer_obj_get_sample_rate);
-const mp_obj_property_t audioio_mixer_sample_rate_obj = {
+const mp_obj_property_t audiomixer_mixer_sample_rate_obj = {
.base.type = &mp_type_property,
- .proxy = {(mp_obj_t)&audioio_mixer_get_sample_rate_obj,
+ .proxy = {(mp_obj_t)&audiomixer_mixer_get_sample_rate_obj,
(mp_obj_t)&mp_const_none_obj,
(mp_obj_t)&mp_const_none_obj},
};
//| .. attribute:: voice
//|
//| A tuple of the mixer's `audioio.MixerVoice` object(s).
//|
//| .. code-block:: python
//|
//| >>> mixer.voice
//| (<MixerVoice>,)
-STATIC mp_obj_t audioio_mixer_obj_get_voice(mp_obj_t self_in) {
- audioio_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
+STATIC mp_obj_t audiomixer_mixer_obj_get_voice(mp_obj_t self_in) {
+ audiomixer_mixer_obj_t *self = MP_OBJ_TO_PTR(self_in);
check_for_deinit(self);
return self->voice_tuple;
}
-MP_DEFINE_CONST_FUN_OBJ_1(audioio_mixer_get_voice_obj, audioio_mixer_obj_get_voice);
+MP_DEFINE_CONST_FUN_OBJ_1(audiomixer_mixer_get_voice_obj, audiomixer_mixer_obj_get_voice);
-const mp_obj_property_t audioio_mixer_voice_obj = {
+const mp_obj_property_t audiomixer_mixer_voice_obj = {
.base.type = &mp_type_property,
- .proxy = {(mp_obj_t)&audioio_mixer_get_voice_obj,
+ .proxy = {(mp_obj_t)&audiomixer_mixer_get_voice_obj,
(mp_obj_t)&mp_const_none_obj,
(mp_obj_t)&mp_const_none_obj},
};
-STATIC const mp_rom_map_elem_t audioio_mixer_locals_dict_table[] = {
+STATIC const mp_rom_map_elem_t audiomixer_mixer_locals_dict_table[] = {
// Methods
- { MP_ROM_QSTR(MP_QSTR_deinit), MP_ROM_PTR(&audioio_mixer_deinit_obj) },
+ { MP_ROM_QSTR(MP_QSTR_deinit), MP_ROM_PTR(&audiomixer_mixer_deinit_obj) },
{ MP_ROM_QSTR(MP_QSTR___enter__), MP_ROM_PTR(&default___enter___obj) },
- { MP_ROM_QSTR(MP_QSTR___exit__), MP_ROM_PTR(&audioio_mixer___exit___obj) },
+ { MP_ROM_QSTR(MP_QSTR___exit__), MP_ROM_PTR(&audiomixer_mixer___exit___obj) },
// Properties
- { MP_ROM_QSTR(MP_QSTR_playing), MP_ROM_PTR(&audioio_mixer_playing_obj) },
- { MP_ROM_QSTR(MP_QSTR_sample_rate), MP_ROM_PTR(&audioio_mixer_sample_rate_obj) },
- { MP_ROM_QSTR(MP_QSTR_voice), MP_ROM_PTR(&audioio_mixer_voice_obj) }
+ { MP_ROM_QSTR(MP_QSTR_playing), MP_ROM_PTR(&audiomixer_mixer_playing_obj) },
+ { MP_ROM_QSTR(MP_QSTR_sample_rate), MP_ROM_PTR(&audiomixer_mixer_sample_rate_obj) },
+ { MP_ROM_QSTR(MP_QSTR_voice), MP_ROM_PTR(&audiomixer_mixer_voice_obj) }
};
-STATIC MP_DEFINE_CONST_DICT(audioio_mixer_locals_dict, audioio_mixer_locals_dict_table);
+STATIC MP_DEFINE_CONST_DICT(audiomixer_mixer_locals_dict, audiomixer_mixer_locals_dict_table);
-const mp_obj_type_t audioio_mixer_type = {
+const mp_obj_type_t audiomixer_mixer_type = {
{ &mp_type_type },
.name = MP_QSTR_Mixer,
- .make_new = audioio_mixer_make_new,
- .locals_dict = (mp_obj_dict_t*)&audioio_mixer_locals_dict,
+ .make_new = audiomixer_mixer_make_new,
+ .locals_dict = (mp_obj_dict_t*)&audiomixer_mixer_locals_dict,
};
@@ -185,59 +186,59 @@ const mp_obj_property_t audioio_mixer_playing_obj = {
//| .. attribute:: voice
//|
-//| A tuple of the mixer's `audioio.MixerVoice` object(s).
+//| A tuple of the mixer's `audiomixer.MixerVoice` object(s).
//|
//| .. code-block:: python